#ifndef GALLERYLOCALCONTENTPROVIDER_H
#define GALLERYLOCALCONTENTPROVIDER_H

#include "gallerycontentprovider.h"
#include <QList>
#include <QUrl>

class QSparqlConnection;
class GalleryLocalContentProviderPrivate;

//! \class GalleryLocalContentProvider
//! \brief GalleryLocalContentProvider is a class for providing a model (content) of local file system.
//! This is a simple class which can be used to provide information of a single file or a set of files.
class GALLERYCORE_EXPORT GalleryLocalContentProvider : public GalleryContentProvider
{
    Q_OBJECT
public:
    //! Constructor.
    //! \param parent optional parent.
    GalleryLocalContentProvider(QObject* parent=0);

    //! Alternative constructor.
    //!
    //! \param sparqlConnection to use for requesting tracker values
    //!        on the local urls
    //! \param parent optional parent.
    GalleryLocalContentProvider(QSparqlConnection *sparqlConnection,
                                QObject* parent=0);

    //! Destructor
    virtual ~GalleryLocalContentProvider();

    //! Sets the contained URLs. The old URLs are replaced by the new ones.
    //! \param urls a new list of URLs
    void setUrls(const QList<QUrl>& urls);

public: // from GalleryContentProvider
    //! \reimp
    virtual void queryContent(int limit=-1);
    //! \reimp
    QAbstractItemModel* model() const;
    //! \reimp
    virtual bool isLoadingContent() const;

private:
    GalleryLocalContentProviderPrivate* d_ptr;
    Q_DECLARE_PRIVATE(GalleryLocalContentProvider);
};

#endif // GALLERYLOCALCONTENTPROVIDER_H
